import click

TPL_DEPS_MAKEFILE = '''\
###############################################################################
#                             requirements: start                             #
###############################################################################
ckan_tag = ckan-2.9.3
ext_list = spatial

remote-spatial = https://github.com/ckan/ckanext-spatial.git branch master

###############################################################################
#                              requirements: end                              #
###############################################################################

_version = master

-include deps.mk

prepare:
	curl -O https://raw.githubusercontent.com/DataShades/ckan-deps-installer/$(_version)/deps.mk
'''


@click.group(short_help="Variety of useful commands.")
def toolbelt():
    """Variety of useful commands.
    """


@toolbelt.group()
def make():
    """Generate, make, produce, print different things.
    """

@make.command()
def deps_makefile():
    """Print to stdout basic Makefile for ckan-deps-installer.

    """
    click.echo(TPL_DEPS_MAKEFILE)



import pytest

from ckanext.toolbelt import decorators


class TestCollector:
    def func(self):
        pass

    def test_basic(self):
        collector, getter = decorators.Collector().split()

        assert getter() == {}

        collector("xxx")(self.func)
        assert getter() == {"xxx": self.func}

        collector(self.func)
        assert getter() == {"xxx": self.func, "func": self.func}

    def test_prefix(self):
        collector, getter = decorators.Collector("toolbelt").split()

        assert getter() == {}

        collector("xxx")(self.func)
        assert getter() == {"xxx": self.func}

        collector(self.func)
        assert getter() == {"xxx": self.func, "toolbelt_func": self.func}

    def test_separator(self):
        collector, getter = decorators.Collector("toolbelt", "-").split()

        assert getter() == {}

        collector("xxx")(self.func)
        assert getter() == {"xxx": self.func}

        collector(self.func)
        assert getter() == {"xxx": self.func, "toolbelt-func": self.func}



import ckan.plugins as plugins
import ckan.plugins.toolkit as toolkit


class ToolbeltPlugin(plugins.SingletonPlugin):
    plugins.implements(plugins.IConfigurer)
    

    # IConfigurer

    def update_config(self, config_):
        toolkit.add_template_directory(config_, "templates")
        toolkit.add_public_directory(config_, "public")
        toolkit.add_resource("assets", "toolbelt")

    
